<?php

App::uses('AppHelper', 'View/Helper');

class CustomFieldsHelper extends AppHelper {

	/**
	 * override this helper and set this to true to set a custom permission level
	 */
	public $allowOverride = false;

	/**
	 * get custom field data from the name for the template
	 *
	 * @param   string      the custom field to get
	 * @param   mixed       Default value if the actual value cannot be found
	 * @param   string      name of the array containing the custom field data (defaults to data)
	 * @return  mixed
	 */
	public function get($name, $default = '', $dataVar = 'data') {
		$dataVar = rtrim($dataVar, '.');
		$customFields = Hash::get($this->_View->viewVars, $dataVar . '.CustomFieldData');
		if ($customFields === null || ! is_array($customFields)) {
			return $default;
		}

		if (isset($customFields[$name])) {
			$value = $customFields[$name];
		} else {
			$fields = Hash::combine($customFields, '{n}.Field.name', '{n}');
			$value = Hash::get($fields, $name . '.FieldData.value');
		}

		if ($value === null) {
			return $default;
		}

		return $value;
	}

	/**
	 *	Uses the get helper method and escapes the result
	 *
	 * @param   string      the custom field to get
	 * @param   mixed       Default value if the actual value cannot be found
	 * @param   string      name of the array containing the custom field data (defaults to data)
	 * @return  mixed
	 *
	 * @return string
	 */
	public function escape($name, $default = '', $dataVar = 'data') {
		$value = $this->get($name, $default, $dataVar);

		return h($value);
	}

	/**
	 * get all the custom field data in one array
	 *
	 * @param   string      name of the array containing the custom field data (defaults to data)
	 * @return  array
	 */
	public function getAll($dataVar = 'data') {
		$dataVar = rtrim($dataVar, '.');
		$customFields = Hash::get($this->_View->viewVars, $dataVar . '.CustomFieldData');
		if ($customFields === null || ! is_array($customFields)) {
			return array();
		}

		$key = key($customFields);
		if (intval($key) > 0) {
			return Hash::combine($customFields, '{n}.Field.name', '{n}.FieldData.value');
		} else {
			return $customFields;
		}
	}

	/**
	 * get all the custom field data in one array and escape it
	 *
	 * @param   string      name of the array containing the custom field data (defaults to data)
	 * @return  array
	 */
	public function escapeAll($dataVar = 'data') {
		$results = $this->getAll($dataVar);
		if (!empty($results)) {
			array_map('h', $results);
		}

		return $results;
	}

	/**
	 * inject the tab into the form
	 *
	 */
	public function injectAdminForm() {
		// check the logged in user to prevent showing the form if they are not an admin
		if (
			$this->Permissions->hasSuperAdminPermission($this->_View->viewVars['authUser']) ||
			(
				intval($this->allowOverride) > 0 &&
				$this->Permissions->hasPermission($this->_View->viewVars['authUser'], $this->allowOverride)
			)
		) {
			echo $this->element(
				'form_tab',
				array(
					'title' => 'Custom Fields',
					'tabContent' => $this->element('EvCustomFields.selection/fieldSelectionTab'),
					'divOptions' => array(
						'class' => 'custom-field-selection'
					)
				)
			);
		}
	}

	/**
	 * clean the attribute array for use on addField
	 *
	 * @param   array   Array of data from the CustomField array
	 * @return  array   Cleaned array for addField - removes names / validation rules
	 */
	public function cleanAttrArray($attr) {

		unset(
			$attr['name'],
			$attr['validation'],
			$attr['model'],
			$attr['model_id'],
			$attr['sequence'],
			$attr['is_active'],
			$attr['created'],
			$attr['modified']
		);

		if (! empty($attr['options'])) {
			$attr['options'] = $this->formatOptions($attr['options']);
		} else {
			unset($attr['options']);
		}
		return $attr;
	}

	/**
	 * format any options the array may have
	 *
	 * @param   array   Options array
	 * @return  array   formatted Options array
	 */
	public function formatOptions($options) {
		if (empty($options) || ! is_array($options)) {
			return array();
		}

		return Hash::combine(
			$options,
			'{n}.value',
			'{n}.label'
		);
	}
}
